==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstNxTunIpv4SrcCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Empty;

/**
 * Class that builds {@link DstNxTunIpv4SrcCaseBuilder} instances.
 *
 * @see DstNxTunIpv4SrcCaseBuilder
 *
 */
public class DstNxTunIpv4SrcCaseBuilder implements Builder<DstNxTunIpv4SrcCase> {

    private Empty _nxTunIpv4Src;


    Map<Class<? extends Augmentation<DstNxTunIpv4SrcCase>>, Augmentation<DstNxTunIpv4SrcCase>> augmentation = Collections.emptyMap();

    public DstNxTunIpv4SrcCaseBuilder() {
    }
    public DstNxTunIpv4SrcCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping arg) {
        this._nxTunIpv4Src = arg.getNxTunIpv4Src();
    }

    public DstNxTunIpv4SrcCaseBuilder(DstNxTunIpv4SrcCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstNxTunIpv4SrcCase>>, Augmentation<DstNxTunIpv4SrcCase>> aug =((AugmentationHolder<DstNxTunIpv4SrcCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxTunIpv4Src = base.getNxTunIpv4Src();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping) {
            this._nxTunIpv4Src = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping)arg).getNxTunIpv4Src();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping]");
    }

    public Empty getNxTunIpv4Src() {
        return _nxTunIpv4Src;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstNxTunIpv4SrcCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstNxTunIpv4SrcCaseBuilder setNxTunIpv4Src(final Empty value) {
        this._nxTunIpv4Src = value;
        return this;
    }
    
    public DstNxTunIpv4SrcCaseBuilder addAugmentation(Class<? extends Augmentation<DstNxTunIpv4SrcCase>> augmentationType, Augmentation<DstNxTunIpv4SrcCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstNxTunIpv4SrcCaseBuilder removeAugmentation(Class<? extends Augmentation<DstNxTunIpv4SrcCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstNxTunIpv4SrcCase build() {
        return new DstNxTunIpv4SrcCaseImpl(this);
    }

    private static final class DstNxTunIpv4SrcCaseImpl
        extends AbstractAugmentable<DstNxTunIpv4SrcCase>
        implements DstNxTunIpv4SrcCase {
    
        private final Empty _nxTunIpv4Src;
    
        DstNxTunIpv4SrcCaseImpl(DstNxTunIpv4SrcCaseBuilder base) {
            super(base.augmentation);
            this._nxTunIpv4Src = base.getNxTunIpv4Src();
        }
    
        @Override
        public Empty getNxTunIpv4Src() {
            return _nxTunIpv4Src;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxTunIpv4Src);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstNxTunIpv4SrcCase.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            DstNxTunIpv4SrcCase other = (DstNxTunIpv4SrcCase)obj;
            if (!Objects.equals(_nxTunIpv4Src, other.getNxTunIpv4Src())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstNxTunIpv4SrcCaseImpl otherImpl = (DstNxTunIpv4SrcCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstNxTunIpv4SrcCase>>, Augmentation<DstNxTunIpv4SrcCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstNxTunIpv4SrcCase");
            CodeHelpers.appendValue(helper, "_nxTunIpv4Src", _nxTunIpv4Src);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstNxTunIpv4SrcCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Empty;

/**
 * Class that builds {@link DstNxTunIpv4SrcCaseBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     DstNxTunIpv4SrcCaseBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new DstNxTunIpv4SrcCaseBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of DstNxTunIpv4SrcCaseBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see DstNxTunIpv4SrcCaseBuilder
 * @see Builder
 *
 */
public class DstNxTunIpv4SrcCaseBuilder implements Builder<DstNxTunIpv4SrcCase> {

    private Empty _nxTunIpv4Src;


    Map<Class<? extends Augmentation<DstNxTunIpv4SrcCase>>, Augmentation<DstNxTunIpv4SrcCase>> augmentation = Collections.emptyMap();

    public DstNxTunIpv4SrcCaseBuilder() {
    }
    public DstNxTunIpv4SrcCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping arg) {
        this._nxTunIpv4Src = arg.getNxTunIpv4Src();
    }

    public DstNxTunIpv4SrcCaseBuilder(DstNxTunIpv4SrcCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstNxTunIpv4SrcCase>>, Augmentation<DstNxTunIpv4SrcCase>> aug =((AugmentationHolder<DstNxTunIpv4SrcCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxTunIpv4Src = base.getNxTunIpv4Src();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping) {
            this._nxTunIpv4Src = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping)arg).getNxTunIpv4Src();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4SrcGrouping]");
    }

    public Empty getNxTunIpv4Src() {
        return _nxTunIpv4Src;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstNxTunIpv4SrcCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstNxTunIpv4SrcCaseBuilder setNxTunIpv4Src(final Empty value) {
        this._nxTunIpv4Src = value;
        return this;
    }
    
    public DstNxTunIpv4SrcCaseBuilder addAugmentation(Class<? extends Augmentation<DstNxTunIpv4SrcCase>> augmentationType, Augmentation<DstNxTunIpv4SrcCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstNxTunIpv4SrcCaseBuilder removeAugmentation(Class<? extends Augmentation<DstNxTunIpv4SrcCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstNxTunIpv4SrcCase build() {
        return new DstNxTunIpv4SrcCaseImpl(this);
    }

    private static final class DstNxTunIpv4SrcCaseImpl
        extends AbstractAugmentable<DstNxTunIpv4SrcCase>
        implements DstNxTunIpv4SrcCase {
    
        private final Empty _nxTunIpv4Src;
    
        DstNxTunIpv4SrcCaseImpl(DstNxTunIpv4SrcCaseBuilder base) {
            super(base.augmentation);
            this._nxTunIpv4Src = base.getNxTunIpv4Src();
        }
    
        @Override
        public Empty getNxTunIpv4Src() {
            return _nxTunIpv4Src;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxTunIpv4Src);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstNxTunIpv4SrcCase.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            DstNxTunIpv4SrcCase other = (DstNxTunIpv4SrcCase)obj;
            if (!Objects.equals(_nxTunIpv4Src, other.getNxTunIpv4Src())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstNxTunIpv4SrcCaseImpl otherImpl = (DstNxTunIpv4SrcCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstNxTunIpv4SrcCase>>, Augmentation<DstNxTunIpv4SrcCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstNxTunIpv4SrcCase");
            CodeHelpers.appendValue(helper, "_nxTunIpv4Src", _nxTunIpv4Src);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
